searchData={"items":[{"type":"module","title":"Deepgram","doc":"Official Elixir SDK for Deepgram's speech-to-text, text-to-speech, and AI agent services.","ref":"Deepgram.html"},{"type":"module","title":"Usage - Deepgram","doc":"First, create a client with your API key:\n\n    iex> _client = Deepgram.new(api_key: \"your-api-key\")\n\nThen use the client to access various services:\n\n    # Speech-to-Text\n    Deepgram.Listen.transcribe_url(client, %{url: \"https://example.com/audio.wav\"})\n\n    # Text-to-Speech\n    Deepgram.Speak.synthesize(client, %{text: \"Hello, world!\"})\n\n    # Text Intelligence\n    Deepgram.Read.analyze(client, %{text: \"Analyze this text.\"})\n\n    # AI Agent\n    Deepgram.Agent.create_session(client, %{})","ref":"Deepgram.html#module-usage"},{"type":"module","title":"Configuration - Deepgram","doc":"The client can be configured with various options:\n\n    client = Deepgram.new(\n      api_key: \"your-api-key\",\n      base_url: \"https://api.deepgram.com\",\n      timeout: 30_000,\n      headers: %{\"Custom-Header\" => \"value\"}\n    )\n\nYou can also use environment variables:\n\n    export DEEPGRAM_API_KEY=\"your-api-key\"\n    export DEEPGRAM_BASE_URL=\"https://api.deepgram.com\"","ref":"Deepgram.html#module-configuration"},{"type":"function","title":"Deepgram.new/1","doc":"Creates a new Deepgram client.","ref":"Deepgram.html#new/1"},{"type":"function","title":"Options - Deepgram.new/1","doc":"- `:api_key` - Your Deepgram API key (required, or set via `DEEPGRAM_API_KEY` env var)\n- `:access_token` - OAuth 2.0 access token (alternative to API key)\n- `:base_url` - Base URL for API requests (default: \"https://api.deepgram.com\")\n- `:timeout` - Request timeout in milliseconds (default: 30_000)\n- `:headers` - Additional HTTP headers (default: %{})\n- `:options` - Additional options (default: %{})","ref":"Deepgram.html#new/1-options"},{"type":"function","title":"Examples - Deepgram.new/1","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> match?(%Deepgram.Client{}, client)\n    true\n\n    iex> client = Deepgram.new(access_token: \"your-access-token\")\n    iex> match?(%Deepgram.Client{}, client)\n    true","ref":"Deepgram.html#new/1-examples"},{"type":"function","title":"Deepgram.version/0","doc":"Returns the current version of the SDK.","ref":"Deepgram.html#version/0"},{"type":"module","title":"Deepgram.Client","doc":"Main client for interacting with the Deepgram API.\n\nThis module provides the main client interface and delegates to specific\nservice modules for different API endpoints.","ref":"Deepgram.Client.html"},{"type":"function","title":"Deepgram.Client.agent/1","doc":"Returns the Agent service module for AI agent operations.","ref":"Deepgram.Client.html#agent/1"},{"type":"function","title":"Deepgram.Client.config/1","doc":"Returns the configuration for the client.","ref":"Deepgram.Client.html#config/1"},{"type":"function","title":"Deepgram.Client.listen/1","doc":"Returns the Listen service module for speech-to-text operations.","ref":"Deepgram.Client.html#listen/1"},{"type":"function","title":"Deepgram.Client.manage/1","doc":"Returns the Manage service module for project and key management.","ref":"Deepgram.Client.html#manage/1"},{"type":"function","title":"Deepgram.Client.new/1","doc":"Creates a new Deepgram client.","ref":"Deepgram.Client.html#new/1"},{"type":"function","title":"Parameters - Deepgram.Client.new/1","doc":"- `config` - A `Deepgram.Config` struct containing configuration options.","ref":"Deepgram.Client.html#new/1-parameters"},{"type":"function","title":"Examples - Deepgram.Client.new/1","doc":"iex> config = Deepgram.Config.new(api_key: \"your-api-key\")\n    iex> client = Deepgram.Client.new(config)\n    %Deepgram.Client{...}","ref":"Deepgram.Client.html#new/1-examples"},{"type":"function","title":"Deepgram.Client.read/1","doc":"Returns the Read service module for text intelligence operations.","ref":"Deepgram.Client.html#read/1"},{"type":"function","title":"Deepgram.Client.speak/1","doc":"Returns the Speak service module for text-to-speech operations.","ref":"Deepgram.Client.html#speak/1"},{"type":"type","title":"Deepgram.Client.t/0","doc":"","ref":"Deepgram.Client.html#t:t/0"},{"type":"module","title":"Deepgram.Config","doc":"Configuration for the Deepgram client.\n\nThis module handles configuration options for the Deepgram client,\nincluding API keys, access tokens, base URLs, and other settings.","ref":"Deepgram.Config.html"},{"type":"function","title":"Deepgram.Config.auth_header/1","doc":"Returns the authorization header value based on the configuration.\n\nPrioritizes access token over API key for authentication.","ref":"Deepgram.Config.html#auth_header/1"},{"type":"function","title":"Deepgram.Config.default_headers/1","doc":"Returns the default HTTP headers for requests.","ref":"Deepgram.Config.html#default_headers/1"},{"type":"function","title":"Deepgram.Config.new/1","doc":"Creates a new configuration.","ref":"Deepgram.Config.html#new/1"},{"type":"function","title":"Options - Deepgram.Config.new/1","doc":"- `:api_key` - Your Deepgram API key (required, or set via `DEEPGRAM_API_KEY` env var)\n- `:access_token` - OAuth 2.0 access token (alternative to API key)\n- `:base_url` - Base URL for API requests (default: \"https://api.deepgram.com\")\n- `:timeout` - Request timeout in milliseconds (default: 30_000)\n- `:headers` - Additional HTTP headers (default: %{})\n- `:options` - Additional options (default: %{})","ref":"Deepgram.Config.html#new/1-options"},{"type":"function","title":"Examples - Deepgram.Config.new/1","doc":"iex> config = Deepgram.Config.new(api_key: \"your-api-key\")\n    %Deepgram.Config{...}\n\n    iex> config = Deepgram.Config.new(access_token: \"your-access-token\")\n    %Deepgram.Config{...}\n\n    iex> config = Deepgram.Config.new()  # Uses DEEPGRAM_API_KEY env var\n    %Deepgram.Config{...}","ref":"Deepgram.Config.html#new/1-examples"},{"type":"type","title":"Deepgram.Config.t/0","doc":"","ref":"Deepgram.Config.html#t:t/0"},{"type":"function","title":"Deepgram.Config.user_agent/0","doc":"Returns the user agent string.","ref":"Deepgram.Config.html#user_agent/0"},{"type":"module","title":"Deepgram.Agent","doc":"AI Voice Agent services for the Deepgram API.\n\nThe `Deepgram.Agent` module provides sophisticated conversational AI capabilities\nthrough Deepgram's AI Voice Agent API. It enables developers to create interactive\nvoice and text-based agents using WebSocket connections for real-time communication.","ref":"Deepgram.Agent.html"},{"type":"module","title":"Key Features - Deepgram.Agent","doc":"* **Conversational AI** - Create intelligent voice and text-based agents\n* **Real-time Interaction** - Maintain continuous WebSocket connections\n* **Speech-to-Text Integration** - Process spoken audio in real-time\n* **Text-to-Speech Response** - Generate natural-sounding voice responses\n* **Function Calling** - Trigger custom functions from agent conversations\n* **Session Management** - Maintain conversational context and state\n* **Multi-modal Input** - Accept both audio and text input\n* **Message Injection** - Add context or system messages to conversations\n* **Dynamic Configuration** - Update agent settings during active sessions","ref":"Deepgram.Agent.html#module-key-features"},{"type":"module","title":"Architecture - Deepgram.Agent","doc":"The Agent module integrates three core components:\n\n1. **Listen** - Speech-to-Text processing (audio input → text)\n2. **Think** - Natural language understanding and reasoning\n3. **Speak** - Text-to-Speech synthesis (text → audio output)","ref":"Deepgram.Agent.html#module-architecture"},{"type":"module","title":"Authentication - Deepgram.Agent","doc":"All functions in this module require a properly configured `Deepgram.Client` struct,\nwhich can be created using `Deepgram.new/1`.\n\nExample:\n\n    # Create client with API key\n    client = Deepgram.new(api_key: System.get_env(\"DEEPGRAM_API_KEY\"))\n    \n    # Or with OAuth token\n    client = Deepgram.new(token: \"your-oauth-token\")","ref":"Deepgram.Agent.html#module-authentication"},{"type":"module","title":"Basic Usage - Deepgram.Agent","doc":"Start an agent session with configuration:\n\n    client = Deepgram.new(api_key: System.get_env(\"DEEPGRAM_API_KEY\"))\n    \n    # Configure agent settings\n    settings = %{\n      agent: %{\n        listen: %{model: \"nova-2\", language: \"en\"},\n        think: %{provider: %{type: \"deepgram\"}, instructions: \"You are a helpful assistant.\"},\n        speak: %{model: \"aura-2-thalia-en\", encoding: \"linear16\"}\n      },\n      greeting: \"Hello! How can I help you today?\"\n    }\n    \n    # Start the agent session\n    {:ok, agent} = Deepgram.Agent.start_session(client, settings)\n\nSend audio data to the agent:\n\n    # Send audio chunks to the agent\n    Deepgram.Agent.send_audio(agent, audio_chunk)\n\nSend text input to the agent:\n\n    # Send text message\n    Deepgram.Agent.send_text(agent, \"What's the weather like today?\")","ref":"Deepgram.Agent.html#module-basic-usage"},{"type":"module","title":"Advanced Usage - Deepgram.Agent","doc":"Handle function calls from the agent:\n\n    # Respond to a function call\n    function_call_id = \"abc123\"\n    result = %{temperature: 72, conditions: \"sunny\", location: \"San Francisco\"}\n    Deepgram.Agent.respond_to_function_call(agent, function_call_id, result)\n\nInject a message into the conversation:\n\n    # Add system message\n    system_message = %{\n      type: \"system_message\",\n      content: \"The user is interested in technical information.\",\n      role: \"system\"\n    }\n    Deepgram.Agent.inject_message(agent, system_message)\n\nUpdate agent configuration during a session:\n\n    # Change agent behavior\n    new_settings = %{\n      agent: %{\n        think: %{instructions: \"You are now a cooking expert assistant.\"}\n      }\n    }\n    Deepgram.Agent.update_settings(agent, new_settings)","ref":"Deepgram.Agent.html#module-advanced-usage"},{"type":"function","title":"Deepgram.Agent.close_session/1","doc":"Closes the agent session.","ref":"Deepgram.Agent.html#close_session/1"},{"type":"function","title":"Parameters - Deepgram.Agent.close_session/1","doc":"- `agent` - The agent WebSocket process PID","ref":"Deepgram.Agent.html#close_session/1-parameters"},{"type":"function","title":"Examples - Deepgram.Agent.close_session/1","doc":"iex> Deepgram.Agent.close_session(agent)\n    :ok","ref":"Deepgram.Agent.html#close_session/1-examples"},{"type":"function","title":"Deepgram.Agent.inject_message/2","doc":"Injects a message into the agent conversation.","ref":"Deepgram.Agent.html#inject_message/2"},{"type":"function","title":"Parameters - Deepgram.Agent.inject_message/2","doc":"- `agent` - The agent WebSocket process PID\n- `message` - Message to inject (see `Deepgram.Types.Agent.inject_message_options/0`)","ref":"Deepgram.Agent.html#inject_message/2-parameters"},{"type":"function","title":"Examples - Deepgram.Agent.inject_message/2","doc":"iex> message = %{\n    ...>   type: \"user_message\",\n    ...>   content: \"What's the weather like?\",\n    ...>   role: \"user\"\n    ...> }\n    iex> Deepgram.Agent.inject_message(agent, message)\n    :ok","ref":"Deepgram.Agent.html#inject_message/2-examples"},{"type":"function","title":"Deepgram.Agent.keepalive/1","doc":"Sends a keepalive message to maintain the connection.","ref":"Deepgram.Agent.html#keepalive/1"},{"type":"function","title":"Parameters - Deepgram.Agent.keepalive/1","doc":"- `agent` - The agent WebSocket process PID","ref":"Deepgram.Agent.html#keepalive/1-parameters"},{"type":"function","title":"Examples - Deepgram.Agent.keepalive/1","doc":"iex> Deepgram.Agent.keepalive(agent)\n    :ok","ref":"Deepgram.Agent.html#keepalive/1-examples"},{"type":"function","title":"Deepgram.Agent.respond_to_function_call/3","doc":"Responds to a function call from the agent.","ref":"Deepgram.Agent.html#respond_to_function_call/3"},{"type":"function","title":"Parameters - Deepgram.Agent.respond_to_function_call/3","doc":"- `agent` - The agent WebSocket process PID\n- `function_call_id` - ID of the function call to respond to\n- `result` - Result of the function call","ref":"Deepgram.Agent.html#respond_to_function_call/3-parameters"},{"type":"function","title":"Examples - Deepgram.Agent.respond_to_function_call/3","doc":"iex> Deepgram.Agent.respond_to_function_call(agent, \"call_123\", %{status: \"success\"})\n    :ok","ref":"Deepgram.Agent.html#respond_to_function_call/3-examples"},{"type":"function","title":"Deepgram.Agent.send_audio/2","doc":"Sends audio data to the agent.","ref":"Deepgram.Agent.html#send_audio/2"},{"type":"function","title":"Parameters - Deepgram.Agent.send_audio/2","doc":"- `agent` - The agent WebSocket process PID\n- `audio_data` - Binary audio data to send","ref":"Deepgram.Agent.html#send_audio/2-parameters"},{"type":"function","title":"Examples - Deepgram.Agent.send_audio/2","doc":"iex> Deepgram.Agent.send_audio(agent, audio_data)\n    :ok","ref":"Deepgram.Agent.html#send_audio/2-examples"},{"type":"function","title":"Deepgram.Agent.send_text/2","doc":"Sends a text message to the agent.","ref":"Deepgram.Agent.html#send_text/2"},{"type":"function","title":"Parameters - Deepgram.Agent.send_text/2","doc":"- `agent` - The agent WebSocket process PID\n- `text` - Text message to send","ref":"Deepgram.Agent.html#send_text/2-parameters"},{"type":"function","title":"Examples - Deepgram.Agent.send_text/2","doc":"iex> Deepgram.Agent.send_text(agent, \"Hello, how are you?\")\n    :ok","ref":"Deepgram.Agent.html#send_text/2-examples"},{"type":"function","title":"Deepgram.Agent.start_session/2","doc":"Starts an AI voice agent WebSocket connection.","ref":"Deepgram.Agent.html#start_session/2"},{"type":"function","title":"Parameters - Deepgram.Agent.start_session/2","doc":"- `client` - A `Deepgram.Client` struct\n- `settings` - Agent configuration settings (see `Deepgram.Types.Agent.settings_options/0`)","ref":"Deepgram.Agent.html#start_session/2-parameters"},{"type":"function","title":"Examples - Deepgram.Agent.start_session/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> settings = %{\n    ...>   agent: %{\n    ...>     listen: %{\n    ...>       model: \"nova-2\",\n    ...>       language: \"en\",\n    ...>       smart_format: true,\n    ...>       encoding: \"linear16\",\n    ...>       sample_rate: 16000,\n    ...>       channels: 1,\n    ...>       interim_results: true,\n    ...>       punctuate: true,\n    ...>       profanity_filter: true,\n    ...>       redact: [\"pci\", \"ssn\"],\n    ...>       endpointing: true,\n    ...>       utterance_end_ms: 1000,\n    ...>       vad_turnoff: 1000,\n    ...>       provider: %{\n    ...>         type: \"deepgram\",\n    ...>         model: \"nova-2\"\n    ...>       }\n    ...>     },\n    ...>     think: %{\n    ...>       provider: %{\n    ...>         type: \"open_ai\",\n    ...>         model: \"gpt-4\"\n    ...>       },\n    ...>       instructions: \"You are a helpful assistant.\",\n    ...>       knowledge: \"\"\n    ...>     },\n    ...>     speak: %{\n    ...>       model: \"aura-2-thalia-en\",\n    ...>       encoding: \"linear16\",\n    ...>       container: \"none\",\n    ...>       sample_rate: 16000,\n    ...>       provider: %{\n    ...>         type: \"deepgram\",\n    ...>         model: \"aura-2-thalia-en\"\n    ...>       }\n    ...>     }\n    ...>   },\n    ...>   version: \"latest\",\n    ...>   format: \"text\",\n    ...>   encoding: \"linear16\",\n    ...>   sample_rate: 16000,\n    ...>   channels: 1,\n    ...>   language: \"en\",\n    ...>   greeting: \"Hello! How can I help you today?\"\n    ...> }\n    iex> {:ok, agent} = Deepgram.Agent.start_session(client, settings)\n    {:ok, #PID<...>}","ref":"Deepgram.Agent.html#start_session/2-examples"},{"type":"function","title":"Deepgram.Agent.update_settings/2","doc":"Updates the agent's configuration.","ref":"Deepgram.Agent.html#update_settings/2"},{"type":"function","title":"Parameters - Deepgram.Agent.update_settings/2","doc":"- `agent` - The agent WebSocket process PID\n- `settings` - New settings to apply","ref":"Deepgram.Agent.html#update_settings/2-parameters"},{"type":"function","title":"Examples - Deepgram.Agent.update_settings/2","doc":"iex> new_settings = %{\n    ...>   agent: %{\n    ...>     think: %{\n    ...>       instructions: \"You are now a cooking assistant.\"\n    ...>     }\n    ...>   }\n    ...> }\n    iex> Deepgram.Agent.update_settings(agent, new_settings)\n    :ok","ref":"Deepgram.Agent.html#update_settings/2-examples"},{"type":"module","title":"Deepgram.Listen","doc":"Speech-to-Text services for the Deepgram API.\n\nThis module provides both prerecorded (REST API) and live (WebSocket API)\nspeech-to-text transcription services. With Deepgram's Speech-to-Text capabilities,\nyou can transcribe audio from various sources with high accuracy and customize the\ntranscription process with a wide range of options.","ref":"Deepgram.Listen.html"},{"type":"module","title":"Key Features - Deepgram.Listen","doc":"* **Multiple Input Sources**: Transcribe audio from URLs or files\n* **Real-time Streaming**: Transcribe live audio streams using WebSockets\n* **Asynchronous Processing**: Process large files with callback support\n* **Advanced Features**: Speaker diarization, punctuation, smart formatting\n* **Language Detection**: Automatic language identification\n* **Custom Models**: Use domain-specific models for higher accuracy","ref":"Deepgram.Listen.html#module-key-features"},{"type":"module","title":"Usage Examples - Deepgram.Listen","doc":"","ref":"Deepgram.Listen.html#module-usage-examples"},{"type":"module","title":"Basic URL Transcription - Deepgram.Listen","doc":"```elixir\nclient = Deepgram.new(api_key: \"your-api-key\")\n{:ok, response} = Deepgram.Listen.transcribe_url(client, %{url: \"https://example.com/audio.wav\"})\n```","ref":"Deepgram.Listen.html#module-basic-url-transcription"},{"type":"module","title":"Enhanced Transcription with Options - Deepgram.Listen","doc":"```elixir\nclient = Deepgram.new(api_key: \"your-api-key\")\n{:ok, response} = Deepgram.Listen.transcribe_url(\n  client, \n  %{url: \"https://example.com/audio.wav\"}, \n  %{\n    model: \"nova-2\",         # Use the Nova-2 model\n    punctuate: true,        # Add punctuation\n    diarize: true,          # Identify different speakers\n    smart_format: true,     # Format numbers, dates, etc.\n    detect_language: true,  # Detect the audio language\n    utterances: true        # Split by speaker turns\n  }\n)\n```","ref":"Deepgram.Listen.html#module-enhanced-transcription-with-options"},{"type":"module","title":"Live Audio Streaming - Deepgram.Listen","doc":"```elixir\n# Start a WebSocket connection\n{:ok, websocket} = Deepgram.Listen.live_transcription(\n  client,\n  %{\n    model: \"nova-2\",\n    interim_results: true,  # Get results as they become available\n    punctuate: true,\n    encoding: \"linear16\",   # Audio encoding format\n    sample_rate: 16000      # Audio sample rate in Hz\n  }\n)\n\n# Send audio chunks\nDeepgram.Listen.WebSocket.send_audio(websocket, audio_chunk)\n\n# Handle incoming messages\nreceive do\n  {:deepgram_result, result} -> \n    # Process transcription result\n  {:deepgram_error, error} -> \n    # Handle error\nend\n```\n\nSee the [examples directory](https://github.com/deepgram/deepgram-elixir-sdk/tree/main/examples) for more detailed usage examples.","ref":"Deepgram.Listen.html#module-live-audio-streaming"},{"type":"function","title":"Deepgram.Listen.live_transcription/2","doc":"Starts a live transcription WebSocket connection.","ref":"Deepgram.Listen.html#live_transcription/2"},{"type":"function","title":"Parameters - Deepgram.Listen.live_transcription/2","doc":"- `client` - A `Deepgram.Client` struct\n- `options` - Optional live transcription options (similar to `t:Deepgram.Types.Listen.prerecorded_options/0`)","ref":"Deepgram.Listen.html#live_transcription/2-parameters"},{"type":"function","title":"Examples - Deepgram.Listen.live_transcription/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> options = %{model: \"nova-2\", interim_results: true}\n    iex> {:ok, websocket} = Deepgram.Listen.live_transcription(client, options)\n    {:ok, #PID<...>}","ref":"Deepgram.Listen.html#live_transcription/2-examples"},{"type":"function","title":"Deepgram.Listen.transcribe_file/3","doc":"Transcribes audio from a file.","ref":"Deepgram.Listen.html#transcribe_file/3"},{"type":"function","title":"Parameters - Deepgram.Listen.transcribe_file/3","doc":"- `client` - A `Deepgram.Client` struct\n- `file_data` - Binary data of the audio file\n- `options` - Optional transcription options (see `Deepgram.Types.Listen.prerecorded_options/0`)","ref":"Deepgram.Listen.html#transcribe_file/3-parameters"},{"type":"function","title":"Examples - Deepgram.Listen.transcribe_file/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, file_data} = File.read(\"path/to/audio.wav\")\n    iex> options = %{model: \"nova-2\", punctuate: true}\n    iex> {:ok, response} = Deepgram.Listen.transcribe_file(client, file_data, options)\n    {:ok, %{metadata: %{...}, results: %{...}}}","ref":"Deepgram.Listen.html#transcribe_file/3-examples"},{"type":"function","title":"Deepgram.Listen.transcribe_file_callback/4","doc":"Transcribes audio from a file with callback support (asynchronous).","ref":"Deepgram.Listen.html#transcribe_file_callback/4"},{"type":"function","title":"Parameters - Deepgram.Listen.transcribe_file_callback/4","doc":"- `client` - A `Deepgram.Client` struct\n- `file_data` - Binary data of the audio file\n- `callback_url` - URL to receive the transcription result\n- `options` - Optional transcription options (see `Deepgram.Types.Listen.prerecorded_options/0`)","ref":"Deepgram.Listen.html#transcribe_file_callback/4-parameters"},{"type":"function","title":"Examples - Deepgram.Listen.transcribe_file_callback/4","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, file_data} = File.read(\"path/to/audio.wav\")\n    iex> callback_url = \"https://example.com/webhook\"\n    iex> options = %{model: \"nova-2\", punctuate: true}\n    iex> {:ok, response} = Deepgram.Listen.transcribe_file_callback(client, file_data, callback_url, options)\n    {:ok, %{request_id: \"...\"}}","ref":"Deepgram.Listen.html#transcribe_file_callback/4-examples"},{"type":"function","title":"Deepgram.Listen.transcribe_url/3","doc":"Transcribes audio from a URL source.","ref":"Deepgram.Listen.html#transcribe_url/3"},{"type":"function","title":"Parameters - Deepgram.Listen.transcribe_url/3","doc":"- `client` - A `Deepgram.Client` struct\n- `source` - A map containing the URL: `%{url: \"https://example.com/audio.wav\"}`\n- `options` - Optional transcription options (see `Deepgram.Types.Listen.prerecorded_options/0`)","ref":"Deepgram.Listen.html#transcribe_url/3-parameters"},{"type":"function","title":"Examples - Deepgram.Listen.transcribe_url/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> source = %{url: \"https://example.com/audio.wav\"}\n    iex> options = %{model: \"nova-2\", punctuate: true}\n    iex> {:ok, response} = Deepgram.Listen.transcribe_url(client, source, options)\n    {:ok, %{metadata: %{...}, results: %{...}}}","ref":"Deepgram.Listen.html#transcribe_url/3-examples"},{"type":"function","title":"Deepgram.Listen.transcribe_url_callback/4","doc":"Transcribes audio from a URL with callback support (asynchronous).","ref":"Deepgram.Listen.html#transcribe_url_callback/4"},{"type":"function","title":"Parameters - Deepgram.Listen.transcribe_url_callback/4","doc":"- `client` - A `Deepgram.Client` struct\n- `source` - A map containing the URL: `%{url: \"https://example.com/audio.wav\"}`\n- `callback_url` - URL to receive the transcription result\n- `options` - Optional transcription options (see `Deepgram.Types.Listen.prerecorded_options/0`)","ref":"Deepgram.Listen.html#transcribe_url_callback/4-parameters"},{"type":"function","title":"Examples - Deepgram.Listen.transcribe_url_callback/4","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> source = %{url: \"https://example.com/audio.wav\"}\n    iex> callback_url = \"https://example.com/webhook\"\n    iex> options = %{model: \"nova-2\", punctuate: true}\n    iex> {:ok, response} = Deepgram.Listen.transcribe_url_callback(client, source, callback_url, options)\n    {:ok, %{request_id: \"...\"}}","ref":"Deepgram.Listen.html#transcribe_url_callback/4-examples"},{"type":"module","title":"Deepgram.Manage","doc":"Management API services for the Deepgram API.\n\nThis module provides project and key management capabilities including\nproject operations, API key management, member management, and usage tracking.","ref":"Deepgram.Manage.html"},{"type":"function","title":"Deepgram.Manage.create_key/3","doc":"Creates a new API key.","ref":"Deepgram.Manage.html#create_key/3"},{"type":"function","title":"Parameters - Deepgram.Manage.create_key/3","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID\n- `options` - Key creation options (see `t:Deepgram.Types.Manage.key_options/0`)","ref":"Deepgram.Manage.html#create_key/3-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.create_key/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> options = %{comment: \"My API key\", scopes: [\"usage:read\"], tags: [\"production\"]}\n    iex> {:ok, key} = Deepgram.Manage.create_key(client, \"project-id\", options)\n    {:ok, %{api_key: %{key_id: \"...\", api_key: \"...\", ...}}}","ref":"Deepgram.Manage.html#create_key/3-examples"},{"type":"function","title":"Deepgram.Manage.delete_key/3","doc":"Deletes an API key.","ref":"Deepgram.Manage.html#delete_key/3"},{"type":"function","title":"Parameters - Deepgram.Manage.delete_key/3","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID\n- `key_id` - The API key ID","ref":"Deepgram.Manage.html#delete_key/3-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.delete_key/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, message} = Deepgram.Manage.delete_key(client, \"project-id\", \"key-id\")\n    {:ok, %{message: \"API key deleted successfully\"}}","ref":"Deepgram.Manage.html#delete_key/3-examples"},{"type":"function","title":"Deepgram.Manage.delete_project/2","doc":"Deletes a project.","ref":"Deepgram.Manage.html#delete_project/2"},{"type":"function","title":"Parameters - Deepgram.Manage.delete_project/2","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID","ref":"Deepgram.Manage.html#delete_project/2-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.delete_project/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, message} = Deepgram.Manage.delete_project(client, \"project-id\")\n    {:ok, %{message: \"Project deleted successfully\"}}","ref":"Deepgram.Manage.html#delete_project/2-examples"},{"type":"function","title":"Deepgram.Manage.get_balances/2","doc":"Gets all balances for a project.","ref":"Deepgram.Manage.html#get_balances/2"},{"type":"function","title":"Parameters - Deepgram.Manage.get_balances/2","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID","ref":"Deepgram.Manage.html#get_balances/2-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.get_balances/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, balances} = Deepgram.Manage.get_balances(client, \"project-id\")\n    {:ok, %{balances: [%{balance_id: \"...\", amount: 100.0, ...}]}}","ref":"Deepgram.Manage.html#get_balances/2-examples"},{"type":"function","title":"Deepgram.Manage.get_key/3","doc":"Gets a specific API key.","ref":"Deepgram.Manage.html#get_key/3"},{"type":"function","title":"Parameters - Deepgram.Manage.get_key/3","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID\n- `key_id` - The API key ID","ref":"Deepgram.Manage.html#get_key/3-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.get_key/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, key} = Deepgram.Manage.get_key(client, \"project-id\", \"key-id\")\n    {:ok, %{api_key: %{key_id: \"...\", api_key: \"...\", ...}}}","ref":"Deepgram.Manage.html#get_key/3-examples"},{"type":"function","title":"Deepgram.Manage.get_keys/2","doc":"Gets all API keys for a project.","ref":"Deepgram.Manage.html#get_keys/2"},{"type":"function","title":"Parameters - Deepgram.Manage.get_keys/2","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID","ref":"Deepgram.Manage.html#get_keys/2-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.get_keys/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, keys} = Deepgram.Manage.get_keys(client, \"project-id\")\n    {:ok, %{api_keys: [%{key_id: \"...\", api_key: \"...\", ...}]}}","ref":"Deepgram.Manage.html#get_keys/2-examples"},{"type":"function","title":"Deepgram.Manage.get_members/2","doc":"Gets all members of a project.","ref":"Deepgram.Manage.html#get_members/2"},{"type":"function","title":"Parameters - Deepgram.Manage.get_members/2","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID","ref":"Deepgram.Manage.html#get_members/2-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.get_members/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, members} = Deepgram.Manage.get_members(client, \"project-id\")\n    {:ok, %{members: [%{member_id: \"...\", email: \"...\", ...}]}}","ref":"Deepgram.Manage.html#get_members/2-examples"},{"type":"function","title":"Deepgram.Manage.get_model/3","doc":"Gets a specific model by ID.","ref":"Deepgram.Manage.html#get_model/3"},{"type":"function","title":"Parameters - Deepgram.Manage.get_model/3","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID\n- `model_id` - The model ID","ref":"Deepgram.Manage.html#get_model/3-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.get_model/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, model} = Deepgram.Manage.get_model(client, \"project-id\", \"model-id\")\n    {:ok, %{name: \"nova-2\", canonical_name: \"...\", ...}}","ref":"Deepgram.Manage.html#get_model/3-examples"},{"type":"function","title":"Deepgram.Manage.get_models/2","doc":"Gets all available models for a project.","ref":"Deepgram.Manage.html#get_models/2"},{"type":"function","title":"Parameters - Deepgram.Manage.get_models/2","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID","ref":"Deepgram.Manage.html#get_models/2-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.get_models/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, models} = Deepgram.Manage.get_models(client, \"project-id\")\n    {:ok, %{stt: [...], tts: [...], read: [...]}}","ref":"Deepgram.Manage.html#get_models/2-examples"},{"type":"function","title":"Deepgram.Manage.get_project/2","doc":"Gets a specific project by ID.","ref":"Deepgram.Manage.html#get_project/2"},{"type":"function","title":"Parameters - Deepgram.Manage.get_project/2","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID","ref":"Deepgram.Manage.html#get_project/2-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.get_project/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, project} = Deepgram.Manage.get_project(client, \"project-id\")\n    {:ok, %{project_id: \"...\", name: \"...\", ...}}","ref":"Deepgram.Manage.html#get_project/2-examples"},{"type":"function","title":"Deepgram.Manage.get_projects/1","doc":"Gets all projects accessible by the API key.","ref":"Deepgram.Manage.html#get_projects/1"},{"type":"function","title":"Parameters - Deepgram.Manage.get_projects/1","doc":"- `client` - A `Deepgram.Client` struct","ref":"Deepgram.Manage.html#get_projects/1-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.get_projects/1","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, projects} = Deepgram.Manage.get_projects(client)\n    {:ok, %{projects: [%{project_id: \"...\", name: \"...\", ...}]}}","ref":"Deepgram.Manage.html#get_projects/1-examples"},{"type":"function","title":"Deepgram.Manage.get_usage_requests/2","doc":"Gets usage requests for a project.","ref":"Deepgram.Manage.html#get_usage_requests/2"},{"type":"function","title":"Parameters - Deepgram.Manage.get_usage_requests/2","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID","ref":"Deepgram.Manage.html#get_usage_requests/2-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.get_usage_requests/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, usage} = Deepgram.Manage.get_usage_requests(client, \"project-id\")\n    {:ok, %{page: 1, limit: 50, requests: [%{request_id: \"...\", ...}]}}","ref":"Deepgram.Manage.html#get_usage_requests/2-examples"},{"type":"function","title":"Deepgram.Manage.get_usage_summary/2","doc":"Gets usage summary for a project.","ref":"Deepgram.Manage.html#get_usage_summary/2"},{"type":"function","title":"Parameters - Deepgram.Manage.get_usage_summary/2","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID","ref":"Deepgram.Manage.html#get_usage_summary/2-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.get_usage_summary/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, usage} = Deepgram.Manage.get_usage_summary(client, \"project-id\")\n    {:ok, %{start: \"...\", end: \"...\", usage: %{...}}}","ref":"Deepgram.Manage.html#get_usage_summary/2-examples"},{"type":"function","title":"Deepgram.Manage.remove_member/3","doc":"Removes a member from a project.","ref":"Deepgram.Manage.html#remove_member/3"},{"type":"function","title":"Parameters - Deepgram.Manage.remove_member/3","doc":"- `client` - A `Deepgram.Client` struct\n- `project_id` - The project ID\n- `member_id` - The member ID","ref":"Deepgram.Manage.html#remove_member/3-parameters"},{"type":"function","title":"Examples - Deepgram.Manage.remove_member/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> {:ok, message} = Deepgram.Manage.remove_member(client, \"project-id\", \"member-id\")\n    {:ok, %{message: \"Member removed successfully\"}}","ref":"Deepgram.Manage.html#remove_member/3-examples"},{"type":"module","title":"Deepgram.Read","doc":"Text Intelligence services for the Deepgram API.\n\nThe `Deepgram.Read` module provides advanced text analysis capabilities through\nDeepgram's Text Intelligence API. It enables developers to extract meaningful insights\nfrom text data through various analysis features.","ref":"Deepgram.Read.html"},{"type":"module","title":"Key Features - Deepgram.Read","doc":"* **Sentiment Analysis** - Determine emotional tone and sentiment polarity in text\n* **Topic Detection** - Identify key topics and themes within content\n* **Intent Recognition** - Understand user goals and intentions from text\n* **Summarization** - Generate concise summaries of longer text content\n* **Entity Recognition** - Identify and extract named entities from text\n* **Combined Analysis** - Run multiple analysis types in a single API call\n* **Custom Model Support** - Use specialized models for different analysis needs","ref":"Deepgram.Read.html#module-key-features"},{"type":"module","title":"Authentication - Deepgram.Read","doc":"All functions in this module require a properly configured `Deepgram.Client` struct,\nwhich can be created using `Deepgram.new/1`.\n\nExample:\n\n    # Create client with API key\n    client = Deepgram.new(api_key: System.get_env(\"DEEPGRAM_API_KEY\"))\n    \n    # Or with OAuth token\n    client = Deepgram.new(token: \"your-oauth-token\")","ref":"Deepgram.Read.html#module-authentication"},{"type":"module","title":"Basic Usage - Deepgram.Read","doc":"Analyze text for sentiment:\n\n    client = Deepgram.new(api_key: System.get_env(\"DEEPGRAM_API_KEY\"))\n    text_source = %{text: \"I love this product! It's amazing and works perfectly.\"}\n    {:ok, response} = Deepgram.Read.analyze_sentiment(client, text_source)\n\nAnalyze text for topics:\n\n    text_source = %{text: \"Let's discuss machine learning and artificial intelligence.\"}\n    {:ok, response} = Deepgram.Read.analyze_topics(client, text_source)\n\nSummarize text content:\n\n    long_text = %{text: \"Long article or document content that needs to be summarized...\"}\n    {:ok, response} = Deepgram.Read.summarize(client, long_text)","ref":"Deepgram.Read.html#module-basic-usage"},{"type":"module","title":"Advanced Usage - Deepgram.Read","doc":"Perform multiple analysis types in a single call:\n\n    text_source = %{text: \"I really enjoyed the customer service. The representative was very helpful.\"}\n    options = %{\n      model: \"nova-2\", \n      sentiment: true,\n      topics: true,\n      intents: true\n    }\n    {:ok, response} = Deepgram.Read.analyze(client, text_source, options)\n\nUse a specific model for summarization:\n\n    {:ok, response} = Deepgram.Read.summarize_with_model(client, long_text, \"nova-2\")","ref":"Deepgram.Read.html#module-advanced-usage"},{"type":"function","title":"Deepgram.Read.analyze/3","doc":"Analyzes text for intelligence features.","ref":"Deepgram.Read.html#analyze/3"},{"type":"function","title":"Parameters - Deepgram.Read.analyze/3","doc":"- `client` - A `Deepgram.Client` struct\n- `text_source` - A map containing the text: `%{text: \"Analyze this text.\"}`\n- `options` - Optional analysis options (see `Deepgram.Types.Read.analyze_options/0`)","ref":"Deepgram.Read.html#analyze/3-parameters"},{"type":"function","title":"Examples - Deepgram.Read.analyze/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> text_source = %{text: \"I love this product! It's amazing and works perfectly.\"}\n    iex> options = %{model: \"nova-2\", sentiment: true, topics: true}\n    iex> {:ok, response} = Deepgram.Read.analyze(client, text_source, options)\n    {:ok, %{metadata: %{...}, results: %{...}}}","ref":"Deepgram.Read.html#analyze/3-examples"},{"type":"function","title":"Deepgram.Read.analyze_intents/3","doc":"Analyzes text for intents.","ref":"Deepgram.Read.html#analyze_intents/3"},{"type":"function","title":"Parameters - Deepgram.Read.analyze_intents/3","doc":"- `client` - A `Deepgram.Client` struct\n- `text_source` - A map containing the text: `%{text: \"Analyze this text.\"}`\n- `options` - Optional analysis options","ref":"Deepgram.Read.html#analyze_intents/3-parameters"},{"type":"function","title":"Examples - Deepgram.Read.analyze_intents/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> text_source = %{text: \"I want to cancel my subscription.\"}\n    iex> {:ok, response} = Deepgram.Read.analyze_intents(client, text_source)\n    {:ok, %{metadata: %{...}, results: %{intents: %{...}}}}","ref":"Deepgram.Read.html#analyze_intents/3-examples"},{"type":"function","title":"Deepgram.Read.analyze_sentiment/3","doc":"Analyzes text for sentiment.","ref":"Deepgram.Read.html#analyze_sentiment/3"},{"type":"function","title":"Parameters - Deepgram.Read.analyze_sentiment/3","doc":"- `client` - A `Deepgram.Client` struct\n- `text_source` - A map containing the text: `%{text: \"Analyze this text.\"}`\n- `options` - Optional analysis options","ref":"Deepgram.Read.html#analyze_sentiment/3-parameters"},{"type":"function","title":"Examples - Deepgram.Read.analyze_sentiment/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> text_source = %{text: \"I love this product!\"}\n    iex> {:ok, response} = Deepgram.Read.analyze_sentiment(client, text_source)\n    {:ok, %{metadata: %{...}, results: %{sentiments: %{...}}}}","ref":"Deepgram.Read.html#analyze_sentiment/3-examples"},{"type":"function","title":"Deepgram.Read.analyze_topics/3","doc":"Analyzes text for topics.","ref":"Deepgram.Read.html#analyze_topics/3"},{"type":"function","title":"Parameters - Deepgram.Read.analyze_topics/3","doc":"- `client` - A `Deepgram.Client` struct\n- `text_source` - A map containing the text: `%{text: \"Analyze this text.\"}`\n- `options` - Optional analysis options","ref":"Deepgram.Read.html#analyze_topics/3-parameters"},{"type":"function","title":"Examples - Deepgram.Read.analyze_topics/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> text_source = %{text: \"Let's discuss machine learning and artificial intelligence.\"}\n    iex> {:ok, response} = Deepgram.Read.analyze_topics(client, text_source)\n    {:ok, %{metadata: %{...}, results: %{topics: %{...}}}}","ref":"Deepgram.Read.html#analyze_topics/3-examples"},{"type":"function","title":"Deepgram.Read.summarize/3","doc":"Summarizes text.","ref":"Deepgram.Read.html#summarize/3"},{"type":"function","title":"Parameters - Deepgram.Read.summarize/3","doc":"- `client` - A `Deepgram.Client` struct\n- `text_source` - A map containing the text: `%{text: \"Text to summarize.\"}`\n- `options` - Optional analysis options","ref":"Deepgram.Read.html#summarize/3-parameters"},{"type":"function","title":"Examples - Deepgram.Read.summarize/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> text_source = %{text: \"Long text that needs to be summarized...\"}\n    iex> {:ok, response} = Deepgram.Read.summarize(client, text_source)\n    {:ok, %{metadata: %{...}, results: %{summary: %{...}}}}","ref":"Deepgram.Read.html#summarize/3-examples"},{"type":"function","title":"Deepgram.Read.summarize_with_model/4","doc":"Summarizes text with a custom model.","ref":"Deepgram.Read.html#summarize_with_model/4"},{"type":"function","title":"Parameters - Deepgram.Read.summarize_with_model/4","doc":"- `client` - A `Deepgram.Client` struct\n- `text_source` - A map containing the text: `%{text: \"Text to summarize.\"}`\n- `model` - Summary model to use (e.g., \"nova-2\")\n- `options` - Optional analysis options","ref":"Deepgram.Read.html#summarize_with_model/4-parameters"},{"type":"function","title":"Examples - Deepgram.Read.summarize_with_model/4","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> text_source = %{text: \"Long text that needs to be summarized...\"}\n    iex> {:ok, response} = Deepgram.Read.summarize_with_model(client, text_source, \"nova-2\")\n    {:ok, %{metadata: %{...}, results: %{summary: %{...}}}}","ref":"Deepgram.Read.html#summarize_with_model/4-examples"},{"type":"module","title":"Deepgram.Speak","doc":"Text-to-Speech services for the Deepgram API.\n\nThe `Deepgram.Speak` module provides comprehensive text-to-speech synthesis capabilities\nthrough Deepgram's API. It offers both synchronous (REST API) and asynchronous streaming\n(WebSocket API) approaches for converting text to natural-sounding speech.","ref":"Deepgram.Speak.html"},{"type":"module","title":"Key Features - Deepgram.Speak","doc":"* **Text-to-Speech Synthesis** - Convert text to high-quality audio\n* **Multiple Voice Models** - Access to various voice models like Aura 2\n* **Voice Customization** - Control pitch, rate, and other voice characteristics\n* **Audio Format Options** - Support for various audio formats and encodings\n* **Streaming TTS** - Real-time text-to-speech via WebSocket connections\n* **SSML Support** - Speech Synthesis Markup Language for fine-grained control\n* **Asynchronous Callbacks** - Send results to a webhook when processing completes","ref":"Deepgram.Speak.html#module-key-features"},{"type":"module","title":"Authentication - Deepgram.Speak","doc":"All functions in this module require a properly configured `Deepgram.Client` struct,\nwhich can be created using `Deepgram.new/1`.\n\nExample:\n\n    # Create client with API key\n    client = Deepgram.new(api_key: System.get_env(\"DEEPGRAM_API_KEY\"))\n    \n    # Or with OAuth token\n    client = Deepgram.new(token: \"your-oauth-token\")","ref":"Deepgram.Speak.html#module-authentication"},{"type":"module","title":"Basic Usage - Deepgram.Speak","doc":"Synthesize text to speech and get audio data:\n\n    client = Deepgram.new(api_key: System.get_env(\"DEEPGRAM_API_KEY\"))\n    text_source = %{text: \"Welcome to Deepgram's text to speech API.\"}\n    options = %{model: \"aura-2-thalia-en\", encoding: \"mp3\"}\n    {:ok, audio_data} = Deepgram.Speak.synthesize(client, text_source, options)\n\nSave synthesized audio to a file:\n\n    {:ok, response} = Deepgram.Speak.save_to_file(client, \"welcome.mp3\", text_source, options)","ref":"Deepgram.Speak.html#module-basic-usage"},{"type":"module","title":"Advanced Usage - Deepgram.Speak","doc":"Using Speech Synthesis Markup Language (SSML):\n\n    # Create request with SSML\n    ssml_source = %{ssml: \"  Welcome to  Deepgram's  API.  \"}\n    {:ok, audio_data} = Deepgram.Speak.synthesize(client, ssml_source, options)\n\nLive streaming synthesis via WebSocket:\n\n    options = %{model: \"aura-2-thalia-en\", encoding: \"mp3\"}\n    {:ok, ws} = Deepgram.Speak.live_synthesis(client, options)","ref":"Deepgram.Speak.html#module-advanced-usage"},{"type":"function","title":"Deepgram.Speak.live_synthesis/2","doc":"Starts a live text-to-speech WebSocket connection.","ref":"Deepgram.Speak.html#live_synthesis/2"},{"type":"function","title":"Parameters - Deepgram.Speak.live_synthesis/2","doc":"- `client` - A `Deepgram.Client` struct\n- `options` - Optional live synthesis options (see `t:Deepgram.Types.Speak.speak_ws_options/0`)","ref":"Deepgram.Speak.html#live_synthesis/2-parameters"},{"type":"function","title":"Examples - Deepgram.Speak.live_synthesis/2","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> options = %{model: \"aura-2-thalia-en\", encoding: \"linear16\"}\n    iex> {:ok, websocket} = Deepgram.Speak.live_synthesis(client, options)\n    {:ok, #PID<...>}","ref":"Deepgram.Speak.html#live_synthesis/2-examples"},{"type":"function","title":"Deepgram.Speak.save_to_file/4","doc":"Synthesizes text to speech and saves it to a file.","ref":"Deepgram.Speak.html#save_to_file/4"},{"type":"function","title":"Parameters - Deepgram.Speak.save_to_file/4","doc":"- `client` - A `Deepgram.Client` struct\n- `file_path` - Path where the audio file should be saved\n- `text_source` - A map containing the text: `%{text: \"Hello, world!\"}`\n- `options` - Optional synthesis options (see `Deepgram.Types.Speak.speak_options/0`)","ref":"Deepgram.Speak.html#save_to_file/4-parameters"},{"type":"function","title":"Examples - Deepgram.Speak.save_to_file/4","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> text_source = %{text: \"Hello, world!\"}\n    iex> options = %{model: \"aura-2-thalia-en\", encoding: \"linear16\"}\n    iex> {:ok, response} = Deepgram.Speak.save_to_file(client, \"output.wav\", text_source, options)\n    {:ok, %{content_type: \"audio/wav\", ...}}","ref":"Deepgram.Speak.html#save_to_file/4-examples"},{"type":"function","title":"Deepgram.Speak.synthesize/3","doc":"Synthesizes text to speech and returns the audio data.","ref":"Deepgram.Speak.html#synthesize/3"},{"type":"function","title":"Parameters - Deepgram.Speak.synthesize/3","doc":"- `client` - A `Deepgram.Client` struct\n- `text_source` - A map containing the text: `%{text: \"Hello, world!\"}`\n- `options` - Optional synthesis options (see `Deepgram.Types.Speak.speak_options/0`)","ref":"Deepgram.Speak.html#synthesize/3-parameters"},{"type":"function","title":"Examples - Deepgram.Speak.synthesize/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> text_source = %{text: \"Hello, world!\"}\n    iex> options = %{model: \"aura-2-thalia-en\", encoding: \"linear16\"}\n    iex> {:ok, audio_data} = Deepgram.Speak.synthesize(client, text_source, options)\n    {:ok, < >}","ref":"Deepgram.Speak.html#synthesize/3-examples"},{"type":"function","title":"Deepgram.Speak.synthesize_callback/4","doc":"Synthesizes text to speech with callback support (asynchronous).","ref":"Deepgram.Speak.html#synthesize_callback/4"},{"type":"function","title":"Parameters - Deepgram.Speak.synthesize_callback/4","doc":"- `client` - A `Deepgram.Client` struct\n- `text_source` - A map containing the text: `%{text: \"Hello, world!\"}`\n- `callback_url` - URL to receive the audio result\n- `options` - Optional synthesis options (see `Deepgram.Types.Speak.speak_options/0`)","ref":"Deepgram.Speak.html#synthesize_callback/4-parameters"},{"type":"function","title":"Examples - Deepgram.Speak.synthesize_callback/4","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> text_source = %{text: \"Hello, world!\"}\n    iex> callback_url = \"https://example.com/webhook\"\n    iex> options = %{model: \"aura-2-thalia-en\", encoding: \"linear16\"}\n    iex> {:ok, response} = Deepgram.Speak.synthesize_callback(client, text_source, callback_url, options)\n    {:ok, %{request_id: \"...\"}}","ref":"Deepgram.Speak.html#synthesize_callback/4-examples"},{"type":"module","title":"Deepgram.Types.Agent","doc":"Types for the Agent (AI Voice Agent) service.","ref":"Deepgram.Types.Agent.html"},{"type":"type","title":"Deepgram.Types.Agent.agent_audio_done_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:agent_audio_done_response/0"},{"type":"type","title":"Deepgram.Types.Agent.agent_config/0","doc":"","ref":"Deepgram.Types.Agent.html#t:agent_config/0"},{"type":"type","title":"Deepgram.Types.Agent.agent_started_speaking_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:agent_started_speaking_response/0"},{"type":"type","title":"Deepgram.Types.Agent.agent_thinking_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:agent_thinking_response/0"},{"type":"type","title":"Deepgram.Types.Agent.close_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:close_response/0"},{"type":"type","title":"Deepgram.Types.Agent.conversation_text_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:conversation_text_response/0"},{"type":"type","title":"Deepgram.Types.Agent.error_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:error_response/0"},{"type":"type","title":"Deepgram.Types.Agent.function_call_request/0","doc":"","ref":"Deepgram.Types.Agent.html#t:function_call_request/0"},{"type":"type","title":"Deepgram.Types.Agent.function_call_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:function_call_response/0"},{"type":"type","title":"Deepgram.Types.Agent.function_def/0","doc":"","ref":"Deepgram.Types.Agent.html#t:function_def/0"},{"type":"type","title":"Deepgram.Types.Agent.inject_message_options/0","doc":"","ref":"Deepgram.Types.Agent.html#t:inject_message_options/0"},{"type":"type","title":"Deepgram.Types.Agent.injection_refused_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:injection_refused_response/0"},{"type":"type","title":"Deepgram.Types.Agent.listen_config/0","doc":"","ref":"Deepgram.Types.Agent.html#t:listen_config/0"},{"type":"type","title":"Deepgram.Types.Agent.open_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:open_response/0"},{"type":"type","title":"Deepgram.Types.Agent.provider/0","doc":"","ref":"Deepgram.Types.Agent.html#t:provider/0"},{"type":"type","title":"Deepgram.Types.Agent.settings_applied_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:settings_applied_response/0"},{"type":"type","title":"Deepgram.Types.Agent.settings_options/0","doc":"","ref":"Deepgram.Types.Agent.html#t:settings_options/0"},{"type":"type","title":"Deepgram.Types.Agent.speak_config/0","doc":"","ref":"Deepgram.Types.Agent.html#t:speak_config/0"},{"type":"type","title":"Deepgram.Types.Agent.think_config/0","doc":"","ref":"Deepgram.Types.Agent.html#t:think_config/0"},{"type":"type","title":"Deepgram.Types.Agent.unhandled_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:unhandled_response/0"},{"type":"type","title":"Deepgram.Types.Agent.user_started_speaking_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:user_started_speaking_response/0"},{"type":"type","title":"Deepgram.Types.Agent.welcome_response/0","doc":"","ref":"Deepgram.Types.Agent.html#t:welcome_response/0"},{"type":"module","title":"Deepgram.Types.Listen","doc":"Types for the Listen (Speech-to-Text) service.","ref":"Deepgram.Types.Listen.html"},{"type":"type","title":"Deepgram.Types.Listen.alternative/0","doc":"","ref":"Deepgram.Types.Listen.html#t:alternative/0"},{"type":"type","title":"Deepgram.Types.Listen.async_response/0","doc":"","ref":"Deepgram.Types.Listen.html#t:async_response/0"},{"type":"type","title":"Deepgram.Types.Listen.channel/0","doc":"","ref":"Deepgram.Types.Listen.html#t:channel/0"},{"type":"type","title":"Deepgram.Types.Listen.close_response/0","doc":"","ref":"Deepgram.Types.Listen.html#t:close_response/0"},{"type":"type","title":"Deepgram.Types.Listen.error_response/0","doc":"","ref":"Deepgram.Types.Listen.html#t:error_response/0"},{"type":"type","title":"Deepgram.Types.Listen.file_source/0","doc":"","ref":"Deepgram.Types.Listen.html#t:file_source/0"},{"type":"type","title":"Deepgram.Types.Listen.live_metadata/0","doc":"","ref":"Deepgram.Types.Listen.html#t:live_metadata/0"},{"type":"type","title":"Deepgram.Types.Listen.live_options/0","doc":"","ref":"Deepgram.Types.Listen.html#t:live_options/0"},{"type":"type","title":"Deepgram.Types.Listen.live_response/0","doc":"","ref":"Deepgram.Types.Listen.html#t:live_response/0"},{"type":"type","title":"Deepgram.Types.Listen.live_result/0","doc":"","ref":"Deepgram.Types.Listen.html#t:live_result/0"},{"type":"type","title":"Deepgram.Types.Listen.metadata/0","doc":"","ref":"Deepgram.Types.Listen.html#t:metadata/0"},{"type":"type","title":"Deepgram.Types.Listen.open_response/0","doc":"","ref":"Deepgram.Types.Listen.html#t:open_response/0"},{"type":"type","title":"Deepgram.Types.Listen.prerecorded_options/0","doc":"","ref":"Deepgram.Types.Listen.html#t:prerecorded_options/0"},{"type":"type","title":"Deepgram.Types.Listen.results/0","doc":"","ref":"Deepgram.Types.Listen.html#t:results/0"},{"type":"type","title":"Deepgram.Types.Listen.source/0","doc":"","ref":"Deepgram.Types.Listen.html#t:source/0"},{"type":"type","title":"Deepgram.Types.Listen.speech_started/0","doc":"","ref":"Deepgram.Types.Listen.html#t:speech_started/0"},{"type":"type","title":"Deepgram.Types.Listen.stream_source/0","doc":"","ref":"Deepgram.Types.Listen.html#t:stream_source/0"},{"type":"type","title":"Deepgram.Types.Listen.transcription_response/0","doc":"","ref":"Deepgram.Types.Listen.html#t:transcription_response/0"},{"type":"type","title":"Deepgram.Types.Listen.unhandled_response/0","doc":"","ref":"Deepgram.Types.Listen.html#t:unhandled_response/0"},{"type":"type","title":"Deepgram.Types.Listen.utterance_end/0","doc":"","ref":"Deepgram.Types.Listen.html#t:utterance_end/0"},{"type":"type","title":"Deepgram.Types.Listen.word/0","doc":"","ref":"Deepgram.Types.Listen.html#t:word/0"},{"type":"module","title":"Deepgram.Types.Manage","doc":"Types for the Manage (Project and Key Management) service.","ref":"Deepgram.Types.Manage.html"},{"type":"type","title":"Deepgram.Types.Manage.balance/0","doc":"","ref":"Deepgram.Types.Manage.html#t:balance/0"},{"type":"type","title":"Deepgram.Types.Manage.balances_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:balances_response/0"},{"type":"type","title":"Deepgram.Types.Manage.invite/0","doc":"","ref":"Deepgram.Types.Manage.html#t:invite/0"},{"type":"type","title":"Deepgram.Types.Manage.invite_options/0","doc":"","ref":"Deepgram.Types.Manage.html#t:invite_options/0"},{"type":"type","title":"Deepgram.Types.Manage.invites_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:invites_response/0"},{"type":"type","title":"Deepgram.Types.Manage.key/0","doc":"","ref":"Deepgram.Types.Manage.html#t:key/0"},{"type":"type","title":"Deepgram.Types.Manage.key_options/0","doc":"","ref":"Deepgram.Types.Manage.html#t:key_options/0"},{"type":"type","title":"Deepgram.Types.Manage.key_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:key_response/0"},{"type":"type","title":"Deepgram.Types.Manage.keys_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:keys_response/0"},{"type":"type","title":"Deepgram.Types.Manage.member/0","doc":"","ref":"Deepgram.Types.Manage.html#t:member/0"},{"type":"type","title":"Deepgram.Types.Manage.members_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:members_response/0"},{"type":"type","title":"Deepgram.Types.Manage.message/0","doc":"","ref":"Deepgram.Types.Manage.html#t:message/0"},{"type":"type","title":"Deepgram.Types.Manage.model/0","doc":"","ref":"Deepgram.Types.Manage.html#t:model/0"},{"type":"type","title":"Deepgram.Types.Manage.model_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:model_response/0"},{"type":"type","title":"Deepgram.Types.Manage.models_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:models_response/0"},{"type":"type","title":"Deepgram.Types.Manage.project/0","doc":"","ref":"Deepgram.Types.Manage.html#t:project/0"},{"type":"type","title":"Deepgram.Types.Manage.projects_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:projects_response/0"},{"type":"type","title":"Deepgram.Types.Manage.scope/0","doc":"","ref":"Deepgram.Types.Manage.html#t:scope/0"},{"type":"type","title":"Deepgram.Types.Manage.scope_options/0","doc":"","ref":"Deepgram.Types.Manage.html#t:scope_options/0"},{"type":"type","title":"Deepgram.Types.Manage.scopes_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:scopes_response/0"},{"type":"type","title":"Deepgram.Types.Manage.usage_request/0","doc":"","ref":"Deepgram.Types.Manage.html#t:usage_request/0"},{"type":"type","title":"Deepgram.Types.Manage.usage_requests_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:usage_requests_response/0"},{"type":"type","title":"Deepgram.Types.Manage.usage_response/0","doc":"","ref":"Deepgram.Types.Manage.html#t:usage_response/0"},{"type":"module","title":"Deepgram.Types.Read","doc":"Types for the Read (Text Intelligence) service.","ref":"Deepgram.Types.Read.html"},{"type":"type","title":"Deepgram.Types.Read.analyze_options/0","doc":"","ref":"Deepgram.Types.Read.html#t:analyze_options/0"},{"type":"type","title":"Deepgram.Types.Read.analyze_response/0","doc":"","ref":"Deepgram.Types.Read.html#t:analyze_response/0"},{"type":"type","title":"Deepgram.Types.Read.intent/0","doc":"","ref":"Deepgram.Types.Read.html#t:intent/0"},{"type":"type","title":"Deepgram.Types.Read.intents/0","doc":"","ref":"Deepgram.Types.Read.html#t:intents/0"},{"type":"type","title":"Deepgram.Types.Read.intents_info/0","doc":"","ref":"Deepgram.Types.Read.html#t:intents_info/0"},{"type":"type","title":"Deepgram.Types.Read.metadata/0","doc":"","ref":"Deepgram.Types.Read.html#t:metadata/0"},{"type":"type","title":"Deepgram.Types.Read.results/0","doc":"","ref":"Deepgram.Types.Read.html#t:results/0"},{"type":"type","title":"Deepgram.Types.Read.sentiment/0","doc":"","ref":"Deepgram.Types.Read.html#t:sentiment/0"},{"type":"type","title":"Deepgram.Types.Read.sentiment_info/0","doc":"","ref":"Deepgram.Types.Read.html#t:sentiment_info/0"},{"type":"type","title":"Deepgram.Types.Read.sentiments/0","doc":"","ref":"Deepgram.Types.Read.html#t:sentiments/0"},{"type":"type","title":"Deepgram.Types.Read.summary/0","doc":"","ref":"Deepgram.Types.Read.html#t:summary/0"},{"type":"type","title":"Deepgram.Types.Read.summary_info/0","doc":"","ref":"Deepgram.Types.Read.html#t:summary_info/0"},{"type":"type","title":"Deepgram.Types.Read.text_source/0","doc":"","ref":"Deepgram.Types.Read.html#t:text_source/0"},{"type":"type","title":"Deepgram.Types.Read.topic/0","doc":"","ref":"Deepgram.Types.Read.html#t:topic/0"},{"type":"type","title":"Deepgram.Types.Read.topics/0","doc":"","ref":"Deepgram.Types.Read.html#t:topics/0"},{"type":"type","title":"Deepgram.Types.Read.topics_info/0","doc":"","ref":"Deepgram.Types.Read.html#t:topics_info/0"},{"type":"module","title":"Deepgram.Types.Speak","doc":"Types for the Speak (Text-to-Speech) service.","ref":"Deepgram.Types.Speak.html"},{"type":"type","title":"Deepgram.Types.Speak.audio_data/0","doc":"","ref":"Deepgram.Types.Speak.html#t:audio_data/0"},{"type":"type","title":"Deepgram.Types.Speak.cleared_response/0","doc":"","ref":"Deepgram.Types.Speak.html#t:cleared_response/0"},{"type":"type","title":"Deepgram.Types.Speak.close_response/0","doc":"","ref":"Deepgram.Types.Speak.html#t:close_response/0"},{"type":"type","title":"Deepgram.Types.Speak.error_response/0","doc":"","ref":"Deepgram.Types.Speak.html#t:error_response/0"},{"type":"type","title":"Deepgram.Types.Speak.flushed_response/0","doc":"","ref":"Deepgram.Types.Speak.html#t:flushed_response/0"},{"type":"type","title":"Deepgram.Types.Speak.open_response/0","doc":"","ref":"Deepgram.Types.Speak.html#t:open_response/0"},{"type":"type","title":"Deepgram.Types.Speak.speak_options/0","doc":"","ref":"Deepgram.Types.Speak.html#t:speak_options/0"},{"type":"type","title":"Deepgram.Types.Speak.speak_response/0","doc":"","ref":"Deepgram.Types.Speak.html#t:speak_response/0"},{"type":"type","title":"Deepgram.Types.Speak.speak_ws_metadata/0","doc":"","ref":"Deepgram.Types.Speak.html#t:speak_ws_metadata/0"},{"type":"type","title":"Deepgram.Types.Speak.speak_ws_options/0","doc":"","ref":"Deepgram.Types.Speak.html#t:speak_ws_options/0"},{"type":"type","title":"Deepgram.Types.Speak.text_source/0","doc":"","ref":"Deepgram.Types.Speak.html#t:text_source/0"},{"type":"type","title":"Deepgram.Types.Speak.unhandled_response/0","doc":"","ref":"Deepgram.Types.Speak.html#t:unhandled_response/0"},{"type":"type","title":"Deepgram.Types.Speak.warning_response/0","doc":"","ref":"Deepgram.Types.Speak.html#t:warning_response/0"},{"type":"module","title":"Deepgram.Error","doc":"Error handling for the Deepgram SDK.\n\nThis module defines various error types that can be raised by the SDK.","ref":"Deepgram.Error.html"},{"type":"function","title":"Deepgram.Error.api_error/3","doc":"Creates an API error from an HTTP response.","ref":"Deepgram.Error.html#api_error/3"},{"type":"function","title":"Deepgram.Error.authentication_error/1","doc":"Creates an authentication error.","ref":"Deepgram.Error.html#authentication_error/1"},{"type":"function","title":"Deepgram.Error.config_error/2","doc":"Creates a configuration error.","ref":"Deepgram.Error.html#config_error/2"},{"type":"function","title":"Deepgram.Error.http_error/2","doc":"Creates an HTTP error.","ref":"Deepgram.Error.html#http_error/2"},{"type":"function","title":"Deepgram.Error.json_error/2","doc":"Creates a JSON parsing error.","ref":"Deepgram.Error.html#json_error/2"},{"type":"function","title":"Deepgram.Error.timeout_error/2","doc":"Creates a timeout error.","ref":"Deepgram.Error.html#timeout_error/2"},{"type":"function","title":"Deepgram.Error.type_error/3","doc":"Creates a type error.","ref":"Deepgram.Error.html#type_error/3"},{"type":"function","title":"Deepgram.Error.websocket_error/2","doc":"Creates a WebSocket error.","ref":"Deepgram.Error.html#websocket_error/2"},{"type":"module","title":"Deepgram.Agent.WebSocket","doc":"WebSocket client for AI voice agent interactions.\n\nThis module provides a WebSocket client that can connect to Deepgram's\nAI voice agent service for real-time conversational AI interactions.","ref":"Deepgram.Agent.WebSocket.html"},{"type":"function","title":"Deepgram.Agent.WebSocket.build_websocket_headers/1","doc":"Builds WebSocket headers for authentication.","ref":"Deepgram.Agent.WebSocket.html#build_websocket_headers/1"},{"type":"function","title":"Deepgram.Agent.WebSocket.build_websocket_url/1","doc":"Builds the WebSocket URL for agent connection.","ref":"Deepgram.Agent.WebSocket.html#build_websocket_url/1"},{"type":"function","title":"Deepgram.Agent.WebSocket.close/1","doc":"Closes the agent session.","ref":"Deepgram.Agent.WebSocket.html#close/1"},{"type":"function","title":"Deepgram.Agent.WebSocket.inject_message/2","doc":"Injects a message into the agent conversation.","ref":"Deepgram.Agent.WebSocket.html#inject_message/2"},{"type":"function","title":"Deepgram.Agent.WebSocket.keepalive/1","doc":"Sends a keepalive message to maintain the connection.","ref":"Deepgram.Agent.WebSocket.html#keepalive/1"},{"type":"function","title":"Deepgram.Agent.WebSocket.respond_to_function_call/3","doc":"Responds to a function call from the agent.","ref":"Deepgram.Agent.WebSocket.html#respond_to_function_call/3"},{"type":"function","title":"Deepgram.Agent.WebSocket.send_audio/2","doc":"Sends audio data to the agent.","ref":"Deepgram.Agent.WebSocket.html#send_audio/2"},{"type":"function","title":"Deepgram.Agent.WebSocket.send_text/2","doc":"Sends a text message to the agent.","ref":"Deepgram.Agent.WebSocket.html#send_text/2"},{"type":"function","title":"Deepgram.Agent.WebSocket.start_link/3","doc":"Starts a WebSocket connection for AI voice agent interactions.","ref":"Deepgram.Agent.WebSocket.html#start_link/3"},{"type":"function","title":"Parameters - Deepgram.Agent.WebSocket.start_link/3","doc":"- `client` - A `Deepgram.Client` struct\n- `settings` - Agent configuration settings\n- `callback_pid` - Optional PID to receive messages (defaults to caller)","ref":"Deepgram.Agent.WebSocket.html#start_link/3-parameters"},{"type":"function","title":"Examples - Deepgram.Agent.WebSocket.start_link/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> settings = %{agent: %{...}, ...}\n    iex> {:ok, agent} = Deepgram.Agent.WebSocket.start_link(client, settings)\n    {:ok, #PID<...>}","ref":"Deepgram.Agent.WebSocket.html#start_link/3-examples"},{"type":"type","title":"Deepgram.Agent.WebSocket.state/0","doc":"","ref":"Deepgram.Agent.WebSocket.html#t:state/0"},{"type":"function","title":"Deepgram.Agent.WebSocket.update_settings/2","doc":"Updates the agent's configuration.","ref":"Deepgram.Agent.WebSocket.html#update_settings/2"},{"type":"module","title":"Deepgram.Listen.WebSocket","doc":"WebSocket client for live speech-to-text transcription.\n\nThis module provides a WebSocket client that can connect to Deepgram's\nlive transcription service for real-time speech-to-text processing.","ref":"Deepgram.Listen.WebSocket.html"},{"type":"function","title":"Deepgram.Listen.WebSocket.build_query_params/1","doc":"Builds query parameters for WebSocket URL.","ref":"Deepgram.Listen.WebSocket.html#build_query_params/1"},{"type":"function","title":"Deepgram.Listen.WebSocket.build_websocket_headers/1","doc":"Builds WebSocket headers for authentication.","ref":"Deepgram.Listen.WebSocket.html#build_websocket_headers/1"},{"type":"function","title":"Deepgram.Listen.WebSocket.build_websocket_url/2","doc":"Builds the WebSocket URL for live transcription.","ref":"Deepgram.Listen.WebSocket.html#build_websocket_url/2"},{"type":"function","title":"Deepgram.Listen.WebSocket.close/1","doc":"Closes the WebSocket connection.","ref":"Deepgram.Listen.WebSocket.html#close/1"},{"type":"function","title":"Parameters - Deepgram.Listen.WebSocket.close/1","doc":"- `websocket` - The WebSocket process PID","ref":"Deepgram.Listen.WebSocket.html#close/1-parameters"},{"type":"function","title":"Examples - Deepgram.Listen.WebSocket.close/1","doc":"iex> Deepgram.Listen.WebSocket.close(websocket)\n    :ok","ref":"Deepgram.Listen.WebSocket.html#close/1-examples"},{"type":"function","title":"Deepgram.Listen.WebSocket.finish/1","doc":"Finishes the transcription session.","ref":"Deepgram.Listen.WebSocket.html#finish/1"},{"type":"function","title":"Parameters - Deepgram.Listen.WebSocket.finish/1","doc":"- `websocket` - The WebSocket process PID","ref":"Deepgram.Listen.WebSocket.html#finish/1-parameters"},{"type":"function","title":"Examples - Deepgram.Listen.WebSocket.finish/1","doc":"iex> Deepgram.Listen.WebSocket.finish(websocket)\n    :ok","ref":"Deepgram.Listen.WebSocket.html#finish/1-examples"},{"type":"function","title":"Deepgram.Listen.WebSocket.send_audio/2","doc":"Sends audio data to the WebSocket.","ref":"Deepgram.Listen.WebSocket.html#send_audio/2"},{"type":"function","title":"Parameters - Deepgram.Listen.WebSocket.send_audio/2","doc":"- `websocket` - The WebSocket process PID\n- `audio_data` - Binary audio data to send","ref":"Deepgram.Listen.WebSocket.html#send_audio/2-parameters"},{"type":"function","title":"Examples - Deepgram.Listen.WebSocket.send_audio/2","doc":"iex> Deepgram.Listen.WebSocket.send_audio(websocket, audio_data)\n    :ok","ref":"Deepgram.Listen.WebSocket.html#send_audio/2-examples"},{"type":"function","title":"Deepgram.Listen.WebSocket.send_keepalive/1","doc":"Sends a keepalive message to the WebSocket.","ref":"Deepgram.Listen.WebSocket.html#send_keepalive/1"},{"type":"function","title":"Parameters - Deepgram.Listen.WebSocket.send_keepalive/1","doc":"- `websocket` - The WebSocket process PID","ref":"Deepgram.Listen.WebSocket.html#send_keepalive/1-parameters"},{"type":"function","title":"Examples - Deepgram.Listen.WebSocket.send_keepalive/1","doc":"iex> Deepgram.Listen.WebSocket.send_keepalive(websocket)\n    :ok","ref":"Deepgram.Listen.WebSocket.html#send_keepalive/1-examples"},{"type":"function","title":"Deepgram.Listen.WebSocket.start_link/3","doc":"Starts a WebSocket connection for live transcription.","ref":"Deepgram.Listen.WebSocket.html#start_link/3"},{"type":"function","title":"Parameters - Deepgram.Listen.WebSocket.start_link/3","doc":"- `client` - A `Deepgram.Client` struct\n- `options` - Live transcription options\n- `callback_pid` - Optional PID to receive messages (defaults to caller)","ref":"Deepgram.Listen.WebSocket.html#start_link/3-parameters"},{"type":"function","title":"Examples - Deepgram.Listen.WebSocket.start_link/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> options = %{model: \"nova-2\", interim_results: true}\n    iex> {:ok, websocket} = Deepgram.Listen.WebSocket.start_link(client, options)\n    {:ok, #PID<...>}","ref":"Deepgram.Listen.WebSocket.html#start_link/3-examples"},{"type":"type","title":"Deepgram.Listen.WebSocket.state/0","doc":"","ref":"Deepgram.Listen.WebSocket.html#t:state/0"},{"type":"module","title":"Deepgram.Speak.WebSocket","doc":"WebSocket client for live text-to-speech synthesis.\n\nThis module provides a WebSocket client that can connect to Deepgram's\nlive text-to-speech service for real-time audio synthesis.","ref":"Deepgram.Speak.WebSocket.html"},{"type":"function","title":"Deepgram.Speak.WebSocket.build_query_params/1","doc":"Builds query parameters for WebSocket URL.","ref":"Deepgram.Speak.WebSocket.html#build_query_params/1"},{"type":"function","title":"Deepgram.Speak.WebSocket.build_websocket_headers/1","doc":"Builds WebSocket headers for authentication.","ref":"Deepgram.Speak.WebSocket.html#build_websocket_headers/1"},{"type":"function","title":"Deepgram.Speak.WebSocket.build_websocket_url/2","doc":"Builds the WebSocket URL for live text-to-speech.","ref":"Deepgram.Speak.WebSocket.html#build_websocket_url/2"},{"type":"function","title":"Deepgram.Speak.WebSocket.clear/1","doc":"Clears the current synthesis buffer.","ref":"Deepgram.Speak.WebSocket.html#clear/1"},{"type":"function","title":"Parameters - Deepgram.Speak.WebSocket.clear/1","doc":"- `websocket` - The WebSocket process PID","ref":"Deepgram.Speak.WebSocket.html#clear/1-parameters"},{"type":"function","title":"Examples - Deepgram.Speak.WebSocket.clear/1","doc":"iex> Deepgram.Speak.WebSocket.clear(websocket)\n    :ok","ref":"Deepgram.Speak.WebSocket.html#clear/1-examples"},{"type":"function","title":"Deepgram.Speak.WebSocket.close/1","doc":"Closes the WebSocket connection.","ref":"Deepgram.Speak.WebSocket.html#close/1"},{"type":"function","title":"Parameters - Deepgram.Speak.WebSocket.close/1","doc":"- `websocket` - The WebSocket process PID","ref":"Deepgram.Speak.WebSocket.html#close/1-parameters"},{"type":"function","title":"Examples - Deepgram.Speak.WebSocket.close/1","doc":"iex> Deepgram.Speak.WebSocket.close(websocket)\n    :ok","ref":"Deepgram.Speak.WebSocket.html#close/1-examples"},{"type":"function","title":"Deepgram.Speak.WebSocket.flush/1","doc":"Flushes the current synthesis buffer.","ref":"Deepgram.Speak.WebSocket.html#flush/1"},{"type":"function","title":"Parameters - Deepgram.Speak.WebSocket.flush/1","doc":"- `websocket` - The WebSocket process PID","ref":"Deepgram.Speak.WebSocket.html#flush/1-parameters"},{"type":"function","title":"Examples - Deepgram.Speak.WebSocket.flush/1","doc":"iex> Deepgram.Speak.WebSocket.flush(websocket)\n    :ok","ref":"Deepgram.Speak.WebSocket.html#flush/1-examples"},{"type":"function","title":"Deepgram.Speak.WebSocket.send_text/2","doc":"Sends text to be synthesized to the WebSocket.","ref":"Deepgram.Speak.WebSocket.html#send_text/2"},{"type":"function","title":"Parameters - Deepgram.Speak.WebSocket.send_text/2","doc":"- `websocket` - The WebSocket process PID\n- `text` - Text to synthesize to speech","ref":"Deepgram.Speak.WebSocket.html#send_text/2-parameters"},{"type":"function","title":"Examples - Deepgram.Speak.WebSocket.send_text/2","doc":"iex> Deepgram.Speak.WebSocket.send_text(websocket, \"Hello, world!\")\n    :ok","ref":"Deepgram.Speak.WebSocket.html#send_text/2-examples"},{"type":"function","title":"Deepgram.Speak.WebSocket.start_link/3","doc":"Starts a WebSocket connection for live text-to-speech synthesis.","ref":"Deepgram.Speak.WebSocket.html#start_link/3"},{"type":"function","title":"Parameters - Deepgram.Speak.WebSocket.start_link/3","doc":"- `client` - A `Deepgram.Client` struct\n- `options` - Live synthesis options\n- `callback_pid` - Optional PID to receive messages (defaults to caller)","ref":"Deepgram.Speak.WebSocket.html#start_link/3-parameters"},{"type":"function","title":"Examples - Deepgram.Speak.WebSocket.start_link/3","doc":"iex> client = Deepgram.new(api_key: \"your-api-key\")\n    iex> options = %{model: \"aura-2-thalia-en\", encoding: \"linear16\"}\n    iex> {:ok, websocket} = Deepgram.Speak.WebSocket.start_link(client, options)\n    {:ok, #PID<...>}","ref":"Deepgram.Speak.WebSocket.html#start_link/3-examples"},{"type":"type","title":"Deepgram.Speak.WebSocket.state/0","doc":"","ref":"Deepgram.Speak.WebSocket.html#t:state/0"},{"type":"exception","title":"Deepgram.Error.ApiError","doc":"Error raised when API requests fail.","ref":"Deepgram.Error.ApiError.html"},{"type":"function","title":"Deepgram.Error.ApiError.new/3","doc":"","ref":"Deepgram.Error.ApiError.html#new/3"},{"type":"type","title":"Deepgram.Error.ApiError.t/0","doc":"","ref":"Deepgram.Error.ApiError.html#t:t/0"},{"type":"exception","title":"Deepgram.Error.AuthenticationError","doc":"Error raised when authentication fails.","ref":"Deepgram.Error.AuthenticationError.html"},{"type":"type","title":"Deepgram.Error.AuthenticationError.t/0","doc":"","ref":"Deepgram.Error.AuthenticationError.html#t:t/0"},{"type":"exception","title":"Deepgram.Error.ConfigError","doc":"Error raised when configuration is invalid.","ref":"Deepgram.Error.ConfigError.html"},{"type":"function","title":"Deepgram.Error.ConfigError.new/2","doc":"","ref":"Deepgram.Error.ConfigError.html#new/2"},{"type":"type","title":"Deepgram.Error.ConfigError.t/0","doc":"","ref":"Deepgram.Error.ConfigError.html#t:t/0"},{"type":"exception","title":"Deepgram.Error.DeepgramError","doc":"Base error for all Deepgram SDK errors.","ref":"Deepgram.Error.DeepgramError.html"},{"type":"function","title":"Deepgram.Error.DeepgramError.new/2","doc":"","ref":"Deepgram.Error.DeepgramError.html#new/2"},{"type":"type","title":"Deepgram.Error.DeepgramError.t/0","doc":"","ref":"Deepgram.Error.DeepgramError.html#t:t/0"},{"type":"exception","title":"Deepgram.Error.HttpError","doc":"Error raised when HTTP requests fail.","ref":"Deepgram.Error.HttpError.html"},{"type":"function","title":"Deepgram.Error.HttpError.new/2","doc":"","ref":"Deepgram.Error.HttpError.html#new/2"},{"type":"type","title":"Deepgram.Error.HttpError.t/0","doc":"","ref":"Deepgram.Error.HttpError.html#t:t/0"},{"type":"exception","title":"Deepgram.Error.JsonError","doc":"Error raised when JSON parsing fails.","ref":"Deepgram.Error.JsonError.html"},{"type":"function","title":"Deepgram.Error.JsonError.new/2","doc":"","ref":"Deepgram.Error.JsonError.html#new/2"},{"type":"type","title":"Deepgram.Error.JsonError.t/0","doc":"","ref":"Deepgram.Error.JsonError.html#t:t/0"},{"type":"exception","title":"Deepgram.Error.TimeoutError","doc":"Error raised when timeout occurs.","ref":"Deepgram.Error.TimeoutError.html"},{"type":"function","title":"Deepgram.Error.TimeoutError.new/2","doc":"","ref":"Deepgram.Error.TimeoutError.html#new/2"},{"type":"type","title":"Deepgram.Error.TimeoutError.t/0","doc":"","ref":"Deepgram.Error.TimeoutError.html#t:t/0"},{"type":"exception","title":"Deepgram.Error.TypeError","doc":"Error raised when there are issues with types or arguments.","ref":"Deepgram.Error.TypeError.html"},{"type":"function","title":"Deepgram.Error.TypeError.new/3","doc":"","ref":"Deepgram.Error.TypeError.html#new/3"},{"type":"type","title":"Deepgram.Error.TypeError.t/0","doc":"","ref":"Deepgram.Error.TypeError.html#t:t/0"},{"type":"exception","title":"Deepgram.Error.WebSocketError","doc":"Error raised when WebSocket connections fail.","ref":"Deepgram.Error.WebSocketError.html"},{"type":"function","title":"Deepgram.Error.WebSocketError.new/2","doc":"","ref":"Deepgram.Error.WebSocketError.html#new/2"},{"type":"type","title":"Deepgram.Error.WebSocketError.t/0","doc":"","ref":"Deepgram.Error.WebSocketError.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to the Deepgram Elixir SDK will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.1.0] - 2025-07-14","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release of the Deepgram Elixir SDK\n- Support for Speech-to-Text (Listen) API\n  - Pre-recorded audio transcription\n  - Live audio transcription via WebSockets\n  - Advanced features: redaction, summarization, sentiment analysis\n- Support for Text-to-Speech (Speak) API\n  - Text-to-audio synthesis\n  - SSML support\n  - Multiple voice models\n  - Streaming synthesis via WebSockets\n- Support for Text Intelligence (Read) API\n  - Sentiment analysis\n  - Topic detection\n  - Intent recognition\n  - Text summarization\n  - Entity recognition\n- Support for AI Voice Agent API\n  - Conversational AI capabilities\n  - Function calling\n  - Session management\n  - Message injection\n- Comprehensive documentation\n  - Module documentation\n  - Livebook examples\n  - Script examples\n  - README with usage instructions","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- N/A (initial release)","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"- N/A (initial release)","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"- N/A (initial release)","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- N/A (initial release)","ref":"changelog.html#fixed"},{"type":"extras","title":"Security - Changelog","doc":"- N/A (initial release)","ref":"changelog.html#security"},{"type":"extras","title":"Deepgram Elixir SDK","doc":"# Deepgram Elixir SDK\n\n[![Hex.pm](https://img.shields.io/hexpm/v/deepgram.svg)](https://hex.pm/packages/deepgram)\n[![Documentation](https://img.shields.io/badge/documentation-hexdocs-blue.svg)](https://hexdocs.pm/deepgram)\n\nUnofficial Elixir SDK for [Deepgram](https://www.deepgram.com/). Power your apps with world-class speech and Language AI models.","ref":"readme.html"},{"type":"extras","title":"Features - Deepgram Elixir SDK","doc":"- **Speech-to-Text**: Convert audio to text with high accuracy\n- **Text-to-Speech**: Generate natural-sounding speech from text\n- **Text Intelligence**: Extract insights from text with sentiment analysis, topic detection, and more\n- **AI Voice Agent**: Build conversational AI applications\n- **Management API**: Manage projects, API keys, and usage\n- **WebSocket Support**: Real-time streaming for live applications\n- **Async/Await**: Full support for asynchronous operations","ref":"readme.html#features"},{"type":"extras","title":"Installation - Deepgram Elixir SDK","doc":"Add `deepgram` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:deepgram, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Deepgram Elixir SDK","doc":"Set your Deepgram API key as an environment variable:\n\n```bash\nexport DEEPGRAM_API_KEY=\"your-deepgram-api-key\"\n```\n\nOr configure it in your application:\n\n```elixir\nconfig :deepgram,\n  api_key: System.get_env(\"DEEPGRAM_API_KEY\")\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Quick Start - Deepgram Elixir SDK","doc":"```elixir\n# Create a client\nclient = Deepgram.new(api_key: \"your-api-key\")\n\n# Transcribe audio from URL\n{:ok, result} = Deepgram.Listen.transcribe_url(client, %{url: \"https://example.com/audio.wav\"})\n\n# Synthesize speech\n{:ok, audio_data} = Deepgram.Speak.synthesize(client, %{text: \"Hello, world!\"})\n\n# Analyze text\n{:ok, analysis} = Deepgram.Read.analyze(client, %{text: \"I love this product!\"}, %{sentiment: true})\n```","ref":"readme.html#quick-start"},{"type":"extras","title":"Documentation - Deepgram Elixir SDK","doc":"","ref":"readme.html#documentation"},{"type":"extras","title":"Speech-to-Text - Deepgram Elixir SDK","doc":"#### Prerecorded Audio\n\n```elixir\n# From URL\n{:ok, result} = Deepgram.Listen.transcribe_url(client, \n  %{url: \"https://example.com/audio.wav\"}, \n  %{model: \"nova-2\", punctuate: true, diarize: true}\n)\n\n# From file\n{:ok, audio_data} = File.read(\"path/to/audio.wav\")\n{:ok, result} = Deepgram.Listen.transcribe_file(client, audio_data, %{model: \"nova-2\"})\n\n# With callback (async)\n{:ok, result} = Deepgram.Listen.transcribe_url_callback(client, \n  %{url: \"https://example.com/audio.wav\"}, \n  \"https://your-callback-url.com/webhook\",\n  %{model: \"nova-2\"}\n)\n```\n\n#### Live Audio Streaming\n\n```elixir\n# Start WebSocket connection\n{:ok, websocket} = Deepgram.Listen.live_transcription(client, %{\n  model: \"nova-2\",\n  interim_results: true,\n  punctuate: true\n})\n\n# Send audio data\nDeepgram.Listen.WebSocket.send_audio(websocket, audio_chunk)\n\n# Handle messages\nreceive do\n  {:deepgram_result, result} -> \n    IO.puts(\"Transcript: #{result[\"channel\"][\"alternatives\"] |> hd |> Map.get(\"transcript\")}\")\n  {:deepgram_error, error} -> \n    IO.puts(\"Error: #{inspect(error)}\")\nend\n```","ref":"readme.html#speech-to-text"},{"type":"extras","title":"Text-to-Speech - Deepgram Elixir SDK","doc":"#### Basic Synthesis\n\n```elixir\n# Generate audio\n{:ok, audio_data} = Deepgram.Speak.synthesize(client, \n  %{text: \"Hello, world!\"}, \n  %{model: \"aura-2-thalia-en\", encoding: \"linear16\"}\n)\n\n# Save to file\n{:ok, response} = Deepgram.Speak.save_to_file(client, \"output.wav\", \n  %{text: \"Hello, world!\"}, \n  %{model: \"aura-2-thalia-en\"}\n)\n```\n\n#### Live Speech Synthesis\n\n```elixir\n# Start WebSocket connection\n{:ok, websocket} = Deepgram.Speak.live_synthesis(client, %{\n  model: \"aura-2-thalia-en\",\n  encoding: \"linear16\",\n  sample_rate: 16000\n})\n\n# Send text to synthesize\nDeepgram.Speak.WebSocket.send_text(websocket, \"Hello, this is streaming text-to-speech!\")\n\n# Handle audio data\nreceive do\n  {:deepgram_audio, audio_data} -> \n    # Play or save audio data\n    File.write(\"output.wav\", audio_data, [:append])\nend\n```","ref":"readme.html#text-to-speech"},{"type":"extras","title":"Text Intelligence - Deepgram Elixir SDK","doc":"```elixir\n# Sentiment analysis\n{:ok, result} = Deepgram.Read.analyze_sentiment(client, %{text: \"I love this product!\"})\n\n# Topic detection\n{:ok, result} = Deepgram.Read.analyze_topics(client, %{text: \"Let's discuss machine learning.\"})\n\n# Intent recognition\n{:ok, result} = Deepgram.Read.analyze_intents(client, %{text: \"I want to cancel my subscription.\"})\n\n# Text summarization\n{:ok, result} = Deepgram.Read.summarize(client, %{text: \"Long text to summarize...\"})\n\n# Combined analysis\n{:ok, result} = Deepgram.Read.analyze(client, %{text: \"Analyze this text\"}, %{\n  sentiment: true,\n  topics: true,\n  intents: true,\n  summarize: true\n})\n```","ref":"readme.html#text-intelligence"},{"type":"extras","title":"AI Voice Agent - Deepgram Elixir SDK","doc":"```elixir\n# Configure agent\nsettings = %{\n  agent: %{\n    listen: %{\n      model: \"nova-2\",\n      language: \"en\",\n      smart_format: true,\n      encoding: \"linear16\",\n      sample_rate: 16000,\n      channels: 1,\n      provider: %{type: \"deepgram\"}\n    },\n    think: %{\n      provider: %{type: \"open_ai\", model: \"gpt-4\"},\n      instructions: \"You are a helpful assistant.\"\n    },\n    speak: %{\n      model: \"aura-2-thalia-en\",\n      encoding: \"linear16\",\n      provider: %{type: \"deepgram\"}\n    }\n  },\n  greeting: \"Hello! How can I help you today?\"\n}\n\n# Start agent session\n{:ok, agent} = Deepgram.Agent.start_session(client, settings)\n\n# Send audio to agent\nDeepgram.Agent.send_audio(agent, audio_chunk)\n\n# Handle agent responses\nreceive do\n  {:deepgram_audio, audio_data} -> \n    # Play agent's speech\n    play_audio(audio_data)\n  {:deepgram_function_call_request, request} -> \n    # Handle function calls\n    result = handle_function_call(request)\n    Deepgram.Agent.respond_to_function_call(agent, request[\"function_call_id\"], result)\nend\n```","ref":"readme.html#ai-voice-agent"},{"type":"extras","title":"Management API - Deepgram Elixir SDK","doc":"```elixir\n# Get projects\n{:ok, projects} = Deepgram.Manage.get_projects(client)\n\n# Create API key\n{:ok, key} = Deepgram.Manage.create_key(client, project_id, %{\n  comment: \"My API key\",\n  scopes: [\"usage:read\", \"usage:write\"]\n})\n\n# Get usage\n{:ok, usage} = Deepgram.Manage.get_usage_summary(client, project_id)\n\n# Get balances\n{:ok, balances} = Deepgram.Manage.get_balances(client, project_id)\n```","ref":"readme.html#management-api"},{"type":"extras","title":"Error Handling - Deepgram Elixir SDK","doc":"The SDK uses tagged tuples for error handling:\n\n```elixir\ncase Deepgram.Listen.transcribe_url(client, %{url: \"invalid-url\"}) do\n  {:ok, result} -> \n    # Handle success\n    IO.puts(\"Transcription: #{result}\")\n  {:error, %Deepgram.Error.ApiError{status_code: 400, message: message}} -> \n    # Handle API error\n    IO.puts(\"API Error: #{message}\")\n  {:error, %Deepgram.Error.HttpError{reason: reason}} -> \n    # Handle HTTP error\n    IO.puts(\"HTTP Error: #{reason}\")\n  {:error, error} -> \n    # Handle other errors\n    IO.puts(\"Error: #{inspect(error)}\")\nend\n```","ref":"readme.html#error-handling"},{"type":"extras","title":"Examples - Deepgram Elixir SDK","doc":"This SDK includes comprehensive examples to help you get started with each feature:","ref":"readme.html#examples"},{"type":"extras","title":"Interactive Livebook Examples - Deepgram Elixir SDK","doc":"Interactive notebooks for exploring SDK features:\n\n- [Speech-to-Text (Listen) Examples](examples/listen/transcription_examples.livemd)\n- [Text-to-Speech (Speak) Examples](examples/speak/tts_examples.livemd)\n- [Text Intelligence (Read) Examples](examples/read/text_intelligence_examples.livemd)\n- [AI Voice Agent Examples](examples/agent/ai_agent_examples.livemd)","ref":"readme.html#interactive-livebook-examples"},{"type":"extras","title":"Script Examples - Deepgram Elixir SDK","doc":"Standalone scripts for quick implementation:\n\n- [Basic Transcription](examples/listen/basic_transcription.exs)\n- [Basic Speech Synthesis](examples/speak/basic_synthesis.exs)\n- [Basic Text Analysis](examples/read/basic_analysis.exs)\n- [Basic Agent Setup](examples/agent/basic_agent_setup.exs)\n\nFor more examples and documentation, see the [examples directory](examples/).","ref":"readme.html#script-examples"},{"type":"extras","title":"Development - Deepgram Elixir SDK","doc":"```bash\n# Install dependencies\nmix deps.get\n\n# Run tests\nmix test\n\n# Generate documentation\nmix docs\n\n# Run linter\nmix credo\n\n# Run type checker\nmix dialyzer\n\n# Check for compilation errors\nmix compile --warnings-as-errors\n```","ref":"readme.html#development"},{"type":"extras","title":"Contributing - Deepgram Elixir SDK","doc":"1. Fork the repository\n2. Create your feature branch (`git checkout -b feature/amazing-feature`)\n3. Commit your changes (`git commit -m 'Add some amazing feature'`)\n4. Push to the branch (`git push origin feature/amazing-feature`)\n5. Open a Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"License - Deepgram Elixir SDK","doc":"This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Support - Deepgram Elixir SDK","doc":"- [Documentation](https://hexdocs.pm/deepgram)\n- [API Reference](https://developers.deepgram.com/reference/)\n- [Discord Community](https://discord.gg/xWRaCDBtW4)\n- [GitHub Issues](https://github.com/deepgram/deepgram-elixir-sdk/issues)\n- [Deepgram Dashboard](https://console.deepgram.com/)","ref":"readme.html#support"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}